@@ -1,3 +1,4 @@
+# $Id: Text.pm 175 2008-11-14 18:04:35Z fish $
 package WWW::MeGa::Item::Text;
 use strict;
 use warnings;
@@ -6,7 +7,6 @@ use warnings;
 
 WWW::MeGa::Item::Text - Representing a text file in L<WWW::MeGa>
 
-
 =head1 DESCRIPTION
 
 See L<WWW::MeGa::Item>
@@ -17,23 +17,22 @@ See L<WWW::MeGa::Item>
 
 use base 'WWW::MeGa::Item';
 
-our $VERSION = '0.09_3';
+our $VERSION = '0.09_4';
 
 
 =head1 data
 
-gets the common data from C<$self->SUPER::data>, puts the text file
+gets the common data from C<SUPER::data>, puts the text file
 content in C<$data->{CONTENT}> and return the data.
 
 =cut
 
 sub data
 {
-	my ($self, @args) = @_;
-	my $data = $self->SUPER::data($self,@args);
+	my $self = shift;
+	my $data = $self->SUPER::data;
 
 	open my $fh, '<', $self->original or die $!;
-	#my @f = <$fh>;
 	$data->{CONTENT} = <$fh>;
 	close $fh;
 	return $data;
